@@ -26,8 +26,8 @@ options:
     state:
         description:
           - Whether the snapshot should exist or not.
-          - C(started) and C(stopped) can only be used with aurora clusters
-          - Support for C(started) and C(stopped) was added in release 6.3.0.
+          - V(started) and V(stopped) can only be used with aurora clusters.
+          - Support for V(started) and V(stopped) was added in release 6.3.0.
         choices: ['present', 'absent', 'started', 'stopped']
         default: 'present'
         type: str
@@ -37,24 +37,24 @@ options:
         type: str
     force_update_password:
         description:
-          - Set to C(true) to update your cluster password with I(master_user_password).
-          - Since comparing passwords to determine if it needs to be updated is not possible this is set to C(false) by default to allow idempotence.
+          - Set to V(true) to update your cluster password with O(master_user_password).
+          - Since comparing passwords to determine if it needs to be updated is not possible this is set to V(false) by default to allow idempotence.
         type: bool
         default: false
     promote:
-        description: Set to C(true) to promote a read replica cluster.
+        description: Set to V(true) to promote a read replica cluster.
         type: bool
         default: false
     purge_cloudwatch_logs_exports:
         description:
-          - Whether or not to disable Cloudwatch logs enabled for the DB cluster that are not provided in I(enable_cloudwatch_logs_exports).
-            Set I(enable_cloudwatch_logs_exports) to an empty list to disable all.
+          - Whether or not to disable Cloudwatch logs enabled for the DB cluster that are not provided in O(enable_cloudwatch_logs_exports).
+            Set O(enable_cloudwatch_logs_exports) to an empty list to disable all.
         type: bool
         default: true
     purge_security_groups:
         description:
-          - Set to C(false) to retain any enabled security groups that aren't specified in the task and are associated with the cluster.
-          - Can be applied to I(vpc_security_group_ids)
+          - Set to V(false) to retain any enabled security groups that aren't specified in the task and are associated with the cluster.
+          - Can be applied to O(vpc_security_group_ids)
         type: bool
         default: true
     wait:
@@ -64,8 +64,8 @@ options:
     # Options that have a corresponding boto3 parameter
     apply_immediately:
         description:
-          - A value that specifies whether modifying a cluster with I(new_db_cluster_identifier) and I(master_user_password)
-            should be applied as soon as possible, regardless of the I(preferred_maintenance_window) setting. If C(false), changes
+          - A value that specifies whether modifying a cluster with O(new_db_cluster_identifier) and O(master_user_password)
+            should be applied as soon as possible, regardless of the O(preferred_maintenance_window) setting. If V(false), changes
             are applied during the next maintenance window.
         type: bool
         default: false
@@ -84,12 +84,12 @@ options:
         type: str
     backtrack_window:
         description:
-          - The target backtrack window, in seconds. To disable backtracking, set this value to C(0).
-          - If specified, this value must be set to a number from C(0) to C(259,200) (72 hours).
+          - The target backtrack window, in seconds. To disable backtracking, set this value to V(0).
+          - If specified, this value must be set to a number from V(0) to V(259,200) (72 hours).
         type: int
     backup_retention_period:
         description:
-          - The number of days for which automated backups are retained (must be within C(1) to C(35)).
+          - The number of days for which automated backups are retained (must be within V(1) to V(35)).
             May be used when creating a new cluster, when restoring from S3, or when modifying a cluster.
         type: int
         default: 1
@@ -125,8 +125,8 @@ options:
     enable_cloudwatch_logs_exports:
         description:
           - A list of log types that need to be enabled for exporting to CloudWatch Logs.
-          - Engine aurora-mysql supports C(audit), C(error), C(general) and C(slowquery).
-          - Engine aurora-postgresql supports C(postgresql).
+          - Engine aurora-mysql supports V(audit), V(error), V(general) and V(slowquery).
+          - Engine aurora-postgresql supports V(postgresql).
         type: list
         elements: str
     deletion_protection:
@@ -165,12 +165,11 @@ options:
         type: bool
     db_cluster_instance_class:
         description:
-          - The compute and memory capacity of each DB instance in the Multi-AZ DB cluster, for example C(db.m6gd.xlarge).
+          - The compute and memory capacity of each DB instance in the Multi-AZ DB cluster, for example V(db.m6gd.xlarge).
           - Not all DB instance classes are available in all Amazon Web Services Regions, or for all database engines.
           - For the full list of DB instance classes and availability for your engine visit
             U(https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Concepts.DBInstanceClass.html).
           - This setting is required to create a Multi-AZ DB cluster.
-          - I(db_cluster_instance_class) require botocore >= 1.23.44.
         type: str
         version_added: 5.5.0
     enable_iam_database_authentication:
@@ -182,26 +181,27 @@ options:
         description:
           - The amount of storage in gibibytes (GiB) to allocate to each DB instance in the Multi-AZ DB cluster.
           - This setting is required to create a Multi-AZ DB cluster.
-          - I(allocated_storage) require botocore >= 1.23.44.
         type: int
         version_added: 5.5.0
     storage_type:
         description:
           - Specifies the storage type to be associated with the DB cluster.
           - This setting is required to create a Multi-AZ DB cluster.
-          - When specified, a value for the I(iops) parameter is required.
-          - I(storage_type) require botocore >= 1.23.44.
-          - Defaults to C(io1).
+          - For multi-AZ DB clusters, O(storage_type) defaults to V(io1) and a value for the O(iops) parameter is required.
+          - For Aurora DB clusters, O(storage_type) defaults to V(aurora) standard.
+          - For mysql and postgres DB clusters, O(storage_type) defaults to V(io1).
+          - Support for V(aurora) and V(aurora-iopt1) was added in release 8.2.0.
         type: str
         choices:
           - io1
+          - aurora
+          - aurora-iopt1
         version_added: 5.5.0
     iops:
         description:
           - The amount of Provisioned IOPS (input/output operations per second) to be initially allocated for each DB instance in the Multi-AZ DB cluster.
           - This setting is required to create a Multi-AZ DB cluster
           - Must be a multiple between .5 and 50 of the storage amount for the DB cluster.
-          - I(iops) require botocore >= 1.23.44.
         type: int
         version_added: 5.5.0
     engine:
@@ -210,9 +210,9 @@ options:
           - The combinaison of I(engine) and I(engine_mode) may not be supported.
           - "See AWS documentation for details:
             L(Amazon RDS Documentation,https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBCluster.html)."
-          - When I(engine=mysql), I(allocated_storage), I(iops) and I(db_cluster_instance_class) must also be specified.
-          - When I(engine=postgres), I(allocated_storage), I(iops) and I(db_cluster_instance_class) must also be specified.
-          - Support for C(postgres) and C(mysql) was added in amazon.aws 5.5.0.
+          - When O(engine=mysql), O(allocated_storage), O(iops) and O(db_cluster_instance_class) must also be specified.
+          - When I(engine=postgres), O(allocated_storage), O(iops) and O(db_cluster_instance_class) must also be specified.
+          - Support for V(postgres) and V(mysql) was added in amazon.aws 5.5.0.
         choices:
           - aurora
           - aurora-mysql
@@ -222,7 +222,7 @@ options:
         type: str
     engine_mode:
         description:
-          - The DB engine mode of the DB cluster. The combination of I(engine) and I(engine_mode) may not be supported.
+          - The DB engine mode of the DB cluster. The combination of O(engine) and O(engine_mode) may not be supported.
           - "See AWS documentation for details:
             L(Amazon RDS Documentation,https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBCluster.html)."
         choices:
@@ -236,12 +236,12 @@ options:
     engine_version:
         description:
           - The version number of the database engine to use.
-          - For Aurora MySQL that could be C(5.6.10a), C(5.7.12).
-          - Aurora PostgreSQL example, C(9.6.3).
+          - For Aurora MySQL that could be V(5.6.10a), V(5.7.12).
+          - Aurora PostgreSQL example, V(9.6.3).
         type: str
     final_snapshot_identifier:
         description:
-          - The DB cluster snapshot identifier of the new DB cluster snapshot created when I(skip_final_snapshot=false).
+          - The DB cluster snapshot identifier of the new DB cluster snapshot created when O(skip_final_snapshot=false).
         type: str
     force_backtrack:
         description:
@@ -252,14 +252,14 @@ options:
         description:
           - The AWS KMS key identifier (the ARN, unless you are creating a cluster in the same account that owns the
             KMS key, in which case the KMS key alias may be used).
-          - If I(replication_source_identifier) specifies an encrypted source Amazon RDS will use the key used toe encrypt the source.
-          - If I(storage_encrypted=true) and and I(replication_source_identifier) is not provided, the default encryption key is used.
+          - If O(replication_source_identifier) specifies an encrypted source Amazon RDS will use the key used toe encrypt the source.
+          - If O(storage_encrypted=true) and and O(replication_source_identifier) is not provided, the default encryption key is used.
         type: str
     master_user_password:
         description:
           - An 8-41 character password for the master database user.
-          - The password can contain any printable ASCII character except C(/), C("), or C(@).
-          - To modify the password use I(force_password_update). Use I(apply immediately) to change
+          - The password can contain any printable ASCII character except V(/), V("), or V(@).
+          - To modify the password use O(force_update_password). Use O(apply_immediately) to change
             the password immediately, otherwise it is updated during the next maintenance window.
         aliases:
           - password
@@ -275,7 +275,7 @@ options:
           - The new DB cluster (lowercase) identifier for the DB cluster when renaming a DB cluster.
           - The identifier must contain from 1 to 63 letters, numbers, or hyphens and the first character must be a
             letter and may not end in a hyphen or contain consecutive hyphens.
-          - Use I(apply_immediately) to rename immediately, otherwise it is updated during the next maintenance window.
+          - Use O(apply_immediately) to rename immediately, otherwise it is updated during the next maintenance window.
         aliases:
           - new_cluster_id
           - new_id
@@ -288,13 +288,13 @@ options:
     port:
         description:
           - The port number on which the instances in the DB cluster accept connections. If not specified, Amazon RDS
-            defaults this to C(3306) if the I(engine) is C(aurora) and c(5432) if the I(engine) is C(aurora-postgresql).
+            defaults this to V(3306) if the O(engine) is V(aurora) and V(5432) if the O(engine) is V(aurora-postgresql).
         type: int
     preferred_backup_window:
         description:
           - The daily time range (in UTC) of at least 30 minutes, during which automated backups are created if automated backups are
-            enabled using I(backup_retention_period). The option must be in the format of "hh24:mi-hh24:mi" and not conflict with
-            I(preferred_maintenance_window).
+            enabled using O(backup_retention_period). The option must be in the format of "hh24:mi-hh24:mi" and not conflict with
+            O(preferred_maintenance_window).
         aliases:
           - backup_window
         type: str
@@ -307,8 +307,8 @@ options:
         type: str
     remove_from_global_db:
         description:
-          - If set to C(true), the cluster will be removed from global DB.
-          - Parameters I(global_cluster_identifier), I(db_cluster_identifier) must be specified when I(remove_from_global_db=true).
+          - If set to V(true), the cluster will be removed from global DB.
+          - Parameters O(global_cluster_identifier), O(db_cluster_identifier) must be specified when O(remove_from_global_db=true).
         type: bool
         required: false
         version_added: 6.5.0
@@ -321,8 +321,8 @@ options:
     restore_to_time:
         description:
           - The UTC date and time to restore the DB cluster to. Must be in the format "2015-03-07T23:45:00Z".
-          - If this is not provided while restoring a cluster, I(use_latest_restorable_time) must be.
-            May not be specified if I(restore_type) is copy-on-write.
+          - If this is not provided while restoring a cluster, O(use_latest_restorable_time) must be.
+            May not be specified if O(restore_type) is copy-on-write.
         type: str
     restore_type:
         description:
@@ -350,10 +350,28 @@ options:
           - The prefix for all of the file names that contain the data used to create the Amazon Aurora DB cluster.
           - If you do not specify a SourceS3Prefix value, then the Amazon Aurora DB cluster is created by using all of the files in the Amazon S3 bucket.
         type: str
+    serverless_v2_scaling_configuration:
+        description:
+          - Contains the scaling configuration of an Aurora Serverless v2 DB cluster.
+        type: dict
+        suboptions:
+          min_capacity:
+            description:
+              - The minimum number of Aurora capacity units (ACUs) for a DB instance in an Aurora Serverless v2 cluster.
+              - ACU values can be specified in in half-step increments, such as V(8), V(8.5), V(9), and so on.
+              - The smallest possible value is V(0.5).
+            type: float
+          max_capacity:
+            description:
+              - The maximum number of Aurora capacity units (ACUs) for a DB instance in an Aurora Serverless v2 cluster.
+              - ACU values can be specified in in half-step increments, such as V(40), V(40.5), V(41), and so on.
+              - The largest possible value is V(128).
+            type: float
+        version_added: 7.3.0
     skip_final_snapshot:
         description:
           - Whether a final DB cluster snapshot is created before the DB cluster is deleted.
-          - If this is C(false), I(final_snapshot_identifier) must be provided.
+          - If this is V(false), O(final_snapshot_identifier) must be provided.
         type: bool
         default: false
     snapshot_identifier:
@@ -385,13 +403,13 @@ options:
         type: bool
     use_earliest_time_on_point_in_time_unavailable:
         description:
-          - If I(backtrack_to) is set to a timestamp earlier than the earliest backtrack time, this value backtracks the DB cluster to
+          - If O(backtrack_to) is set to a timestamp earlier than the earliest backtrack time, this value backtracks the DB cluster to
             the earliest possible backtrack time. Otherwise, an error occurs.
         type: bool
     use_latest_restorable_time:
         description:
-          - Whether to restore the DB cluster to the latest restorable backup time. Only one of I(use_latest_restorable_time)
-            and I(restore_to_time) may be provided.
+          - Whether to restore the DB cluster to the latest restorable backup time. Only one of O(use_latest_restorable_time)
+            and O(restore_to_time) may be provided.
         type: bool
     vpc_security_group_ids:
         description:
@@ -402,7 +420,7 @@ options:
 
 EXAMPLES = r"""
 # Note: These examples do not set authentication details, see the AWS Guide for details.
-- name: Create minimal aurora cluster in default VPC and default subnet group
+- name: Create minimal Aurora cluster in default VPC and default subnet group
   amazon.aws.rds_cluster:
     cluster_id: "{{ cluster_id }}"
     engine: "aurora"
@@ -434,7 +452,7 @@ EXAMPLES = r"""
     new_cluster_id: "cluster-{{ resource_prefix }}-renamed"
     apply_immediately: true
 
-- name: Delete aurora cluster without creating a final snapshot
+- name: Delete Aurora cluster without creating a final snapshot
   amazon.aws.rds_cluster:
     engine: aurora
     password: "{{ password }}"
@@ -513,7 +531,7 @@ activity_stream_status:
   description: The status of the database activity stream.
   returned: always
   type: str
-  sample: stopped
+  sample: "stopped"
 allocated_storage:
   description:
     - The allocated storage size in gigabytes. Since aurora storage size is not fixed this is
@@ -528,6 +546,11 @@ associated_roles:
   returned: always
   type: list
   sample: []
+auto_minor_version_upgrade:
+  description: Specifies whether minor engine upgrades are applied automatically to the DB cluster during the maintenance window.
+  returned: always
+  type: bool
+  sample: true
 availability_zones:
   description: The list of availability zones that instances in the DB cluster can be created in.
   returned: always
@@ -550,7 +573,7 @@ cluster_create_time:
   description: The time in UTC when the DB cluster was created.
   returned: always
   type: str
-  sample: '2018-06-29T14:08:58.491000+00:00'
+  sample: "2018-06-29T14:08:58.491000+00:00"
 copy_tags_to_snapshot:
   description:
     - Specifies whether tags are copied from the DB cluster to snapshots of the DB cluster.
@@ -572,7 +595,7 @@ db_cluster_identifier:
   description: The lowercase user-supplied DB cluster identifier.
   returned: always
   type: str
-  sample: rds-cluster-demo
+  sample: "rds-cluster-demo"
 db_cluster_members:
   description:
     - A list of dictionaries containing information about the instances in the cluster.
@@ -585,17 +608,17 @@ db_cluster_parameter_group:
   description: The parameter group associated with the DB cluster.
   returned: always
   type: str
-  sample: default.aurora5.6
+  sample: "default.aurora5.6"
 db_cluster_resource_id:
   description: The AWS Region-unique, immutable identifier for the DB cluster.
   returned: always
   type: str
-  sample: cluster-D2MEQDN3BQNXDF74K6DQJTHASU
+  sample: "cluster-D2MEQDN3BQNXDF74K6DQJTHASU"
 db_subnet_group:
   description: The name of the subnet group associated with the DB Cluster.
   returned: always
   type: str
-  sample: default
+  sample: "default"
 deletion_protection:
   description:
     - Indicates if the DB cluster has deletion protection enabled.
@@ -613,32 +636,32 @@ earliest_restorable_time:
   description: The earliest time to which a database can be restored with point-in-time restore.
   returned: always
   type: str
-  sample: '2018-06-29T14:09:34.797000+00:00'
+  sample: "2018-06-29T14:09:34.797000+00:00"
 endpoint:
   description: The connection endpoint for the primary instance of the DB cluster.
   returned: always
   type: str
-  sample: rds-cluster-demo.cluster-cvlrtwiennww.us-east-1.rds.amazonaws.com
+  sample: "rds-cluster-demo.cluster-cvlrtwiennww.us-east-1.rds.amazonaws.com"
 engine:
   description: The database engine of the DB cluster.
   returned: always
   type: str
-  sample: aurora
+  sample: "aurora"
 engine_mode:
   description: The DB engine mode of the DB cluster.
   returned: always
   type: str
-  sample: provisioned
+  sample: "provisioned"
 engine_version:
   description: The database engine version.
   returned: always
   type: str
-  sample: 5.6.10a
+  sample: "5.6.10a"
 hosted_zone_id:
   description: The ID that Amazon Route 53 assigns when you create a hosted zone.
   returned: always
   type: str
-  sample: Z2R2ITUGPM61AM
+  sample: "Z2R2ITUGPM61AM"
 http_endpoint_enabled:
   description:
     - A value that indicates whether the HTTP endpoint for an Aurora Serverless DB cluster is enabled.
@@ -654,12 +677,12 @@ latest_restorable_time:
   description: The latest time to which a database can be restored with point-in-time restore.
   returned: always
   type: str
-  sample: '2018-06-29T14:09:34.797000+00:00'
+  sample: "2018-06-29T14:09:34.797000+00:00"
 master_username:
   description: The master username for the DB cluster.
   returned: always
   type: str
-  sample: username
+  sample: "username"
 multi_az:
   description: Whether the DB cluster has instances in multiple availability zones.
   returned: always
@@ -674,12 +697,12 @@ preferred_backup_window:
   description: The UTC weekly time range during which system maintenance can occur.
   returned: always
   type: str
-  sample: 10:18-10:48
+  sample: "10:18-10:48"
 preferred_maintenance_window:
   description: The UTC weekly time range during which system maintenance can occur.
   returned: always
   type: str
-  sample: tue:03:23-tue:03:53
+  sample: "tue:03:23-tue:03:53"
 read_replica_identifiers:
   description: A list of read replica ID strings associated with the DB cluster.
   returned: always
@@ -689,12 +712,21 @@ reader_endpoint:
   description: The reader endpoint for the DB cluster.
   returned: always
   type: str
-  sample: rds-cluster-demo.cluster-ro-cvlrtwiennww.us-east-1.rds.amazonaws.com
+  sample: "rds-cluster-demo.cluster-ro-cvlrtwiennww.us-east-1.rds.amazonaws.com"
+serverless_v2_scaling_configuration:
+  description: The scaling configuration for an Aurora Serverless v2 DB cluster.
+  returned: when configured
+  type: dict
+  sample: {
+      "max_capacity": 4.5,
+      "min_capacity": 2.5
+  }
+  version_added: 7.3.0
 status:
   description: The status of the DB cluster.
   returned: always
   type: str
-  sample: available
+  sample: "available"
 storage_encrypted:
   description: Whether the DB cluster is storage encrypted.
   returned: always
@@ -727,12 +759,12 @@ vpc_security_groups:
       description: Status of the security group.
       returned: always
       type: str
-      sample: active
+      sample: "active"
     vpc_security_group_id:
       description: Security group of the cluster.
       returned: always
       type: str
-      sample: sg-12345678
+      sample: "sg-12345678"
 """
 
 try:
@@ -821,6 +853,7 @@ def get_create_options(params_dict):
         "StorageType",
         "Iops",
         "EngineMode",
+        "ServerlessV2ScalingConfiguration",
     ]
 
     return dict((k, v) for k, v in params_dict.items() if k in options and v is not None)
@@ -855,6 +888,7 @@ def get_modify_options(params_dict, force_update_password):
         "StorageType",
         "Iops",
         "EngineMode",
+        "ServerlessV2ScalingConfiguration",
     ]
     modify_options = dict((k, v) for k, v in params_dict.items() if k in options and v is not None)
     if not force_update_password:
@@ -1075,6 +1109,10 @@ def changing_cluster_options(modify_params, current_cluster):
             changing_params["DBClusterParameterGroupName"] = desired_db_cluster_parameter_group
 
     for param in modify_params:
+        # describe_db_clusters does not return StorageType for clusters with storage config as "aurora standard"
+        if param == "StorageType":
+            changing_params[param] = modify_params[param]
+            continue
         if modify_params[param] != current_cluster[param]:
             changing_params[param] = modify_params[param]
 
@@ -1086,11 +1124,15 @@ def changing_cluster_options(modify_params, current_cluster):
     if module.params["state"] == "started":
         if current_cluster["Engine"] in ["mysql", "postgres"]:
             module.fail_json("Only aurora clusters can use the state started")
+        # start_db_cluster supports only DBClusterIdentifier
+        changing_params = {}
         changing_params["DBClusterIdentifier"] = db_cluster_id
 
     if module.params["state"] == "stopped":
         if current_cluster["Engine"] in ["mysql", "postgres"]:
             module.fail_json("Only aurora clusters can use the state stopped")
+        # stop_db_cluster supports only DBClusterIdentifier
+        changing_params = {}
         changing_params["DBClusterIdentifier"] = db_cluster_id
 
     return changing_params
@@ -1145,7 +1187,7 @@ def ensure_present(cluster, parameters, method_name, method_options_name):
     return changed
 
 
-def handle_remove_from_global_db(module, cluster):
+def handle_remove_from_global_db(cluster):
     global_cluster_id = module.params.get("global_cluster_identifier")
     db_cluster_id = module.params.get("db_cluster_identifier")
     db_cluster_arn = cluster["DBClusterArn"]
@@ -1212,7 +1254,7 @@ def main():
         engine_mode=dict(choices=["provisioned", "serverless", "parallelquery", "global", "multimaster"]),
         engine_version=dict(),
         allocated_storage=dict(type="int"),
-        storage_type=dict(type="str", choices=["io1"]),
+        storage_type=dict(type="str", choices=["io1", "aurora", "aurora-iopt1"]),
         iops=dict(type="int"),
         final_snapshot_identifier=dict(),
         force_backtrack=dict(type="bool"),
@@ -1232,6 +1274,13 @@ def main():
         s3_bucket_name=dict(),
         s3_ingestion_role_arn=dict(),
         s3_prefix=dict(),
+        serverless_v2_scaling_configuration=dict(
+            type="dict",
+            options=dict(
+                min_capacity=dict(type="float"),
+                max_capacity=dict(type="float"),
+            ),
+        ),
         skip_final_snapshot=dict(type="bool", default=False),
         snapshot_identifier=dict(),
         source_db_cluster_identifier=dict(),
@@ -1292,6 +1341,16 @@ def main():
                 if not module.params.get("storage_type"):
                     module.params["storage_type"] = "io1"
 
+    if module.params.get("engine") and module.params["engine"] in ("aurora", "aurora-mysql", "aurora-postgresql"):
+        if not module.check_mode and module.params.get("storage_type"):
+            module.params["storage_type"] = "aurora"
+
+    if module.params.get("storage_type") and module.params["storage_type"] in ("aurora", "aurora-iopt1"):
+        if module.params.get("engine") not in ("aurora", "aurora-mysql", "aurora-postgresql"):
+            module.fail_json(
+                f"storage_type={module.params['storage_type']} is only supported for aurora engines 'aurora', 'aurora-mysql', 'aurora-postgresql'"
+            )
+
     module.params["db_cluster_identifier"] = module.params["db_cluster_identifier"].lower()
     cluster = get_cluster(module.params["db_cluster_identifier"])
 
@@ -1325,7 +1384,7 @@ def main():
         if method_name == "delete_db_cluster":
             if cluster and module.params.get("remove_from_global_db"):
                 if cluster["Engine"] in ["aurora", "aurora-mysql", "aurora-postgresql"]:
-                    changed = handle_remove_from_global_db(module, cluster)
+                    changed = handle_remove_from_global_db(cluster)
 
             call_method(client, module, method_name, eval(method_options_name)(parameters))
             changed = True
@@ -1341,7 +1400,7 @@ def main():
         if cluster["Engine"] in ["aurora", "aurora-mysql", "aurora-postgresql"]:
             if changed:
                 wait_for_cluster_status(client, module, cluster_id, "cluster_available")
-        changed |= handle_remove_from_global_db(module, cluster)
+        changed |= handle_remove_from_global_db(cluster)
 
     result = camel_dict_to_snake_dict(get_cluster(cluster_id))
 
