@@ -171,7 +171,7 @@ options:
       - See Purity//FB documentation for detailed description.
       - Only available from Purity//FB 3.1.1
     type: bool
-    default: True
+    default: true
   export_policy:
     description:
     - Name of NFS export policy to assign to filesystem
@@ -179,13 +179,41 @@ options:
     - Only valid for Purity//FB 3.3.0 or higher
     type: str
     version_added: "1.9.0"
+  share_policy:
+    description:
+    - Name of SMB share policy to assign to filesystem
+    - Only valid with REST 2.10 or higher
+    - Remove policy with empty string
+    type: str
+    version_added: "1.12.0"
+  client_policy:
+    description:
+    - Name of SMB client policy to assign to filesystem
+    - Only valid with REST 2.10 or higher
+    - Remove policy with empty string
+    type: str
+    version_added: "1.12.0"
+  continuous_availability:
+    description:
+    - Defines if the file system will be continuously available during
+      disruptive scenarios such as network disruption, blades failover, etc
+    type: bool
+    default: true
+    version_added: "1.15.0"
+  group_ownership:
+    description:
+    - The group ownership for new files and directories in a file system
+    type: str
+    choices: [ 'creator', 'parent-directory' ]
+    default: creator
+    version_added: "1.17.0"
 extends_documentation_fragment:
     - purestorage.flashblade.purestorage.fb
 """
 
 EXAMPLES = """
 - name: Create new filesystem named foo
-  purefb_fs:
+  purestorage.flashblade.purefb_fs:
     name: foo
     size: 1T
     state: present
@@ -193,21 +221,21 @@ EXAMPLES = """
     api_token: T-55a68eb5-c785-4720-a2ca-8b03903bf641
 
 - name: Delete filesystem named foo
-  purefb_fs:
+  purestorage.flashblade.purefb_fs:
     name: foo
     state: absent
     fb_url: 10.10.10.2
     api_token: T-55a68eb5-c785-4720-a2ca-8b03903bf641
 
 - name: Recover filesystem named foo
-  purefb_fs:
+  purestorage.flashblade.purefb_fs:
     name: foo
     state: present
     fb_url: 10.10.10.2
     api_token: T-55a68eb5-c785-4720-a2ca-8b03903bf641
 
 - name: Eradicate filesystem named foo
-  purefb_fs:
+  purestorage.flashblade.purefb_fs:
     name: foo
     state: absent
     eradicate: true
@@ -215,25 +243,25 @@ EXAMPLES = """
     api_token: T-55a68eb5-c785-4720-a2ca-8b03903bf641
 
 - name: Promote filesystem named foo ready for failover
-  purefb_fs:
+  purestorage.flashblade.purefb_fs:
     name: foo
     promote: true
     fb_url: 10.10.10.2
     api_token: T-55a68eb5-c785-4720-a2ca-8b03903bf641
 
 - name: Demote filesystem named foo after failover
-  purefb_fs:
+  purestorage.flashblade.purefb_fs:
     name: foo
     promote: false
     fb_url: 10.10.10.2
     api_token: T-55a68eb5-c785-4720-a2ca-8b03903bf641
 
 - name: Modify attributes of an existing filesystem named foo
-  purefb_fs:
+  purestorage.flashblade.purefb_fs:
     name: foo
     size: 2T
-    nfsv3 : false
-    nfsv4 : true
+    nfsv3: false
+    nfsv4: true
     user_quota: 10K
     group_quota: 25M
     nfs_rules: '10.21.200.0/24(ro)'
@@ -243,7 +271,8 @@ EXAMPLES = """
     smb: true
     state: present
     fb_url: 10.10.10.2
-    api_token: T-55a68eb5-c785-4720-a2ca-8b03903bf641"""
+    api_token: T-55a68eb5-c785-4720-a2ca-8b03903bf641
+"""
 
 RETURN = """
 """
@@ -267,6 +296,7 @@ try:
         FileSystemPatch,
         NfsPatch,
         Reference,
+        Smb,
     )
 except ImportError:
     HAS_PYPURECLIENT = False
@@ -290,6 +320,9 @@ NFSV4_API_VERSION = "1.6"
 REPLICATION_API_VERSION = "1.9"
 MULTIPROTOCOL_API_VERSION = "1.11"
 EXPORT_POLICY_API_VERSION = "2.3"
+SMB_POLICY_API_VERSION = "2.10"
+CA_API_VERSION = "2.12"
+GOWNER_API_VERSION = "2.13"
 
 
 def get_fs(module, blade):
@@ -346,10 +379,9 @@ def create_fs(module, blade):
                             if module.params["safeguard_acls"] and (
                                 module.params["access_control"]
                                 in ["mode-bits", "independent"]
-                                or module.params["smb"]
                             ):
                                 module.fail_json(
-                                    msg="ACL Safeguarding cannot be enabled with SMB or if access_control is mode-bits or independent."
+                                    msg="ACL Safeguarding cannot be enabled if access_control is mode-bits or independent."
                                 )
                             fs_obj = FileSystem(
                                 name=module.params["name"],
@@ -488,12 +520,86 @@ def create_fs(module, blade):
                         res.errors[0].message,
                     )
                 )
+        if SMB_POLICY_API_VERSION in api_version:
+            system = get_system(module)
+            if module.params["client_policy"]:
+                export_attr = FileSystemPatch(
+                    smb=Smb(
+                        client_policy=Reference(name=module.params["client_policy"])
+                    )
+                )
+                res = system.patch_file_systems(
+                    names=[module.params["name"]], file_system=export_attr
+                )
+                if res.status_code != 200:
+                    module.fail_json(
+                        msg="Filesystem {0} created, but failed to assign client "
+                        "policy {1}. Error: {2}".format(
+                            module.params["name"],
+                            module.params["client_policy"],
+                            res.errors[0].message,
+                        )
+                    )
+            if module.params["share_policy"]:
+                export_attr = FileSystemPatch(
+                    smb=Smb(share_policy=Reference(name=module.params["share_policy"]))
+                )
+                res = system.patch_file_systems(
+                    names=[module.params["name"]], file_system=export_attr
+                )
+                if res.status_code != 200:
+                    module.fail_json(
+                        msg="Filesystem {0} created, but failed to assign share "
+                        "policy {1}. Error: {2}".format(
+                            module.params["name"],
+                            module.params["share_policy"],
+                            res.errors[0].message,
+                        )
+                    )
+            if CA_API_VERSION in api_version:
+                ca_attr = FileSystemPatch(
+                    smb=Smb(
+                        continuous_availability_enabled=module.params[
+                            "continuous_availability"
+                        ]
+                    )
+                )
+                res = system.patch_file_systems(
+                    names=[module.params["name"]], file_system=ca_attr
+                )
+                if res.status_code != 200:
+                    module.fail_json(
+                        msg="Filesystem {0} created, but failed to set continuous availability"
+                        "Error: {1}".format(
+                            module.params["name"],
+                            res.errors[0].message,
+                        )
+                    )
+            if GOWNER_API_VERSION in api_version and module.params["group_ownership"]:
+                go_attr = FileSystemPatch(
+                    group_ownership=module.params["group_ownership"]
+                )
+                res = system.patch_file_systems(
+                    names=[module.params["name"]], file_system=go_attr
+                )
+                if res.status_code != 200:
+                    module.fail_json(
+                        msg="Filesystem {0} created, but failed to set group ownership"
+                        "Error: {1}".format(
+                            module.params["name"],
+                            res.errors[0].message,
+                        )
+                    )
+
     module.exit_json(changed=changed)
 
 
 def modify_fs(module, blade):
     """Modify Filesystem"""
     changed = False
+    change_export = False
+    change_share = False
+    change_ca = False
     mod_fs = False
     attr = {}
     if module.params["policy"] and module.params["policy_state"] == "present":
@@ -689,7 +795,7 @@ def modify_fs(module, blade):
                             module.params["name"]
                         )
                     )
-                attr["requested_promotion_state"] = module.params["promote"]
+                attr["requested_promotion_state"] = "demoted"
                 mod_fs = True
     if mod_fs:
         changed = True
@@ -721,12 +827,12 @@ def modify_fs(module, blade):
                             module.params["name"], message
                         )
                     )
+    system = get_system(module)
+    current_fs = list(
+        system.get_file_systems(filter="name='" + module.params["name"] + "'").items
+    )[0]
     if EXPORT_POLICY_API_VERSION in api_version and module.params["export_policy"]:
-        system = get_system(module)
         change_export = False
-        current_fs = list(
-            system.get_file_systems(filter="name='" + module.params["name"] + "'").items
-        )[0]
         if (
             current_fs.nfs.export_policy.name
             and current_fs.nfs.export_policy.name != module.params["export_policy"]
@@ -752,8 +858,103 @@ def modify_fs(module, blade):
                         res.errors[0].message,
                     )
                 )
+    if SMB_POLICY_API_VERSION in api_version and module.params["client_policy"]:
+        change_client = False
+        if (
+            current_fs.smb.client_policy.name
+            and current_fs.smb.client_policy.name != module.params["client_policy"]
+        ):
+            change_client = True
+        if not current_fs.smb.client_policy.name and module.params["client_policy"]:
+            change_client = True
+        if change_client and not module.check_mode:
+            client_attr = FileSystemPatch(
+                smb=Smb(client_policy=Reference(name=module.params["client_policy"]))
+            )
+            res = system.patch_file_systems(
+                names=[module.params["name"]], file_system=client_attr
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Failed to modify client policy {1} for "
+                    "filesystem {0}. Error: {2}".format(
+                        module.params["name"],
+                        module.params["client_policy"],
+                        res.errors[0].message,
+                    )
+                )
+    if SMB_POLICY_API_VERSION in api_version and module.params["share_policy"]:
+        change_share = False
+        if (
+            current_fs.smb.share_policy.name
+            and current_fs.smb.share_policy.name != module.params["share_policy"]
+        ):
+            change_share = True
+        if not current_fs.smb.share_policy.name and module.params["share_policy"]:
+            change_share = True
+        if change_share and not module.check_mode:
+            share_attr = FileSystemPatch(
+                smb=Smb(share_policy=Reference(name=module.params["share_policy"]))
+            )
+            res = system.patch_file_systems(
+                names=[module.params["name"]], file_system=share_attr
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Failed to modify share policy {1} for "
+                    "filesystem {0}. Error: {2}".format(
+                        module.params["name"],
+                        module.params["share_policy"],
+                        res.errors[0].message,
+                    )
+                )
+    if CA_API_VERSION in api_version:
+        change_ca = False
+        if (
+            module.params["continuous_availability"]
+            != current_fs.smb.continuous_availability_enabled
+        ):
+            change_ca = True
+        if not module.check_mode and change_ca:
+            ca_attr = FileSystemPatch(
+                smb=Smb(
+                    continuous_availability_enabled=module.params[
+                        "continuous_availability"
+                    ]
+                )
+            )
+            res = system.patch_file_systems(
+                names=[module.params["name"]], file_system=ca_attr
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Failed to modify continuous availability for "
+                    "filesystem {0}. Error: {1}".format(
+                        module.params["name"],
+                        res.errors[0].message,
+                    )
+                )
+    if GOWNER_API_VERSION in api_version:
+        change_go = False
+        if module.params["group_ownership"] != current_fs.group_ownership:
+            change_go = True
+        if not module.check_mode and change_go:
+            go_attr = FileSystemPatch(group_ownership=module.params["group_ownership"])
+            res = system.patch_file_systems(
+                names=[module.params["name"]], file_system=go_attr
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Failed to modify group ownership for "
+                    "filesystem {0}. Error: {1}".format(
+                        module.params["name"],
+                        res.errors[0].message,
+                    )
+                )
 
-    module.exit_json(changed=changed)
+    module.exit_json(
+        changed=(changed or change_export or change_share or change_ca or change_go)
+    )
 
 
 def _delete_fs(module, blade):
@@ -792,7 +993,7 @@ def _delete_fs(module, blade):
             ),
         )
 
-    blade.file_systems.delete_file_systems(module.params["name"])
+    blade.file_systems.delete_file_systems(name=module.params["name"])
 
 
 def delete_fs(module, blade):
@@ -898,6 +1099,9 @@ def main():
             smb_aclmode=dict(
                 type="str", default="shared", choices=["shared", "native"]
             ),
+            group_ownership=dict(
+                choices=["creator", "parent-directory"], default="creator"
+            ),
             policy_state=dict(default="present", choices=["present", "absent"]),
             state=dict(default="present", choices=["present", "absent"]),
             delete_link=dict(default=False, type="bool"),
@@ -910,6 +1114,9 @@ def main():
             ),
             size=dict(type="str"),
             export_policy=dict(type="str"),
+            share_policy=dict(type="str"),
+            client_policy=dict(type="str"),
+            continuous_availability=dict(type="bool", default="true"),
         )
     )
 
